import socket

class DebugSender:
    def __init__(self, port):
        self.port = port
        self.address = ('127.0.0.1', port)
        self.sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)

    def write(self, message):
        if not isinstance(message, bytes):
            message = message.encode('utf-8')
        self.sock.sendto(message, self.address)

    def close(self):
        self.sock.close()

if __name__ == "__main__":
    udp_sender = DebugSender(9999)  # replace 9999 with your desired port
    udp_sender.write("Hello, UDP!")
    udp_sender.close()



from pydantic import BaseModel, create_model
from typing import Type, get_type_hints

class Validator(object):
    @classmethod
    def generate_schema(cls, input_class: Type, allow_additional: bool = False) -> str:
        # Retrieve type hints from the input class
        annotations = get_type_hints(input_class)

        # Create a Pydantic model dynamically
        dynamic_model = create_model(
            'DynamicModel',
            **{name: (annotations[name], ...) for name in annotations},
            __config__=type('Config', (), {'extra': 'allow' if allow_additional else 'forbid'})
        )

        return dynamic_model.schema_json(indent=2)


from setuptools import setup, find_packages

print(find_packages())

setup(
    name="dtac-tools",
    version="0.8.26",
    packages=find_packages(),
    install_requires=[
        "cryptography>=3.4.8",
        "grpcio>=1.59.2",
        "protobuf>=4.25.0",
        "pydantic>=1.10.0",
        "setuptools>=59.6.0",
    ]
)